Glossary
========

.. glossary::
    :sorted:

    HYTEC
      Here is the definition of HYTEC.

    VTK
      The Visualization Toolkit is an open-source software system for 3D
      computer graphics, image processing and scientific visualization. VTK
      is distributed under the OSI-approved BSD 3-clause License.
      It powers :term:`PARAVIEW` and is one of the output format supported
      by :term:`HYTEC`. See https://vtk.org/.

    PARAVIEW
      ParaView is an open-source multiple-platform application for interactive,
      scientific visualization. It has a client–server architecture to
      facilitate remote visualization of datasets, and generates level of
      detail models to maintain interactive frame rates for large datasets.
      See https://www.paraview.org/.
